@@ -13,11 +13,7 @@ pub use udp::UdpSocket;
 
 use std::io;
 
-pub use std::net::{
-    IpAddr, Ipv4Addr, Ipv6Addr, 
-    Shutdown, 
-    SocketAddr, SocketAddrV4, SocketAddrV6
-};
+pub use std::net::{IpAddr, Ipv4Addr, Ipv6Addr, Shutdown, SocketAddr, SocketAddrV4, SocketAddrV6};
 
 pub use std::net::AddrParseError;
 
