@@ -6,6 +6,7 @@ pub use {
 
 pub use {
     crate::net::{connect, polling, transport},
+    crate::platform::byte_pool::{Allocate, ByteBuffer, BytePool, Realloc},
     crate::platform::{channel, dup, wait_group::WaitGroup},
 };
 
@@ -20,3 +21,6 @@ pub use executor::{Executor, MonoExecutor};
 
 mod local;
 pub use local::LocalExecutor;
+
+pub use crate::net::transport::UdpSocket;
+pub use crate::net::transport::{Incoming, TcpListener, TcpStream};
